@@ -1,6 +1,6 @@
-sharpen.wmppp <- function(...)
+sharpen.wmppp <- function(X, ...)
 {
-  X <- sharpen.ppp(...)
+  X <- sharpen.ppp(X, ...)
   class(X) <- c("wmppp", "ppp")
   return(X)
 }
@@ -23,9 +23,16 @@ superimpose.wmppp <- function(...)
   return(X)
 }
 
-unique.wmppp <- function(...)
+unique.wmppp <- function(x, ...)
 {
-  X <- unique.ppp(...)
+  X <- unique.ppp(x, ...)
+  class(X) <- c("wmppp", "ppp")
+  return(X)
+}
+
+"[.wmppp" <- function(i, j, drop=FALSE, ..., clip=FALSE)
+{
+  X <- "[.ppp"(i, j, drop=drop, ..., clip=clip)
   class(X) <- c("wmppp", "ppp")
   return(X)
 }
